<?php

class SmartpackOrderHtml
{
    protected $smartpack_rates;
    protected $smartpack_api;
    protected $post_type;
    protected $sp_method_key_id;
    protected $wooOrder;

    public function __construct(WC_Order $wooOrder)
    {
        try {
            $this->smartpack_api = SmartpackAPI::instance();
            
            $this->post_type = get_post_type($wooOrder->get_id());
            $this->wooOrder = $wooOrder;
            if (method_exists($wooOrder, 'get_shipping_methods')) {
                $arr = $wooOrder->get_shipping_methods();
                $woo_method_id = "";

                if ($arr) {

                    // Reset hack. Gets the first value of the array
                    // and resets its internal pointer
                    $woo_method = reset($arr);
                    $woo_method_id = $woo_method->get_meta('delivery_method', true);
                    if (!$woo_method_id) {
                        $woo_method_id = $woo_method["method_id"];
                    }
                }
            } else {
                $woo_method_id = $wooOrder->shipping_method->get_meta('delivery_method');
            }

            $this->sp_method_key_id = $woo_method_id;
        } catch (Exception $e) {
            echo "<em>Smartpack plugin activated but not configured. Configure it now under WooCommerce > Settings > Shipping > Shipping options</em>";
            return;
        }
    }

    /**
     * Render HTML which allows the shop
     * to change subscription information
     * in WooCommerce
     *
     * (Returns void, but passes data to WC output buffering)
     *
     * @return void
     */
    public function render_html()
    {
        $p = $_GET['post'];
        echo <<<HTML
            <p class="form-field form-field-wide wc-order-smartpack">
			    <label>Smartpack Checkout:</label>
                <a href='post.php?post={$p}&action=edit&smartpack=edit'>Edit Deliverymethod</a>
		    </p>
HTML;

        if ($this->post_type == 'shop_order') {
            if ($_GET['smartpack'] == 'edit') {
                $this->render_table_start();
                $this->render_shipping_change();
                $this->render_table_end();
            }
        }
    }


    /**
     * Pass the start of the table to
     * WC output buffering
     *
     * @return void
     */
    protected function render_table_start()
    {
        echo '<div class="postbox" id="smartpack_backend">';
        echo '<h3>Smartpack Checkout</h3>';
        echo '<div class="inside">';
        echo '<table style="margin-left: 10px; width: 100%; ">';
    }

    /**
     * Render a list of selectable shipping
     * rates to use instead of the current rate
     *
     * @return void
     */
    protected function render_shipping_change()
    {
        $get_droppoints = false;

        echo <<<HTML
            <tr>
                <td colspan="2">
                    <hr>
                </td>
            </tr>
            <tr>
                <td colspan="2">
                    <select name="sp_method_key" id="sp_method_key">
HTML;

        $this->smartpack_rates = $this->smartpack_api->getShippingRates();



        // Hacky URLEncode inside Nowdocs
        $fn = 'urlencode';
        foreach ($this->smartpack_rates as $rate) {
            $attr = '';

            if ($rate['code'] == $this->sp_method_key_id) {
                $attr = 'selected';
            }


            $name = esc_html($rate["name"]);
            $value = esc_attr($rate['code'] . '::' . urlencode($rate['name']));

            echo <<<HTML
                <option value="{$value}" {$attr}>{$name}</option>
HTML;

            if ($this->sp_method_key_id == $rate["code"] && $rate["isDropPoint"]) {
                $get_droppoints = true;
            }
        }


        echo <<<HTML
            </select>&nbsp;
            <a class="button button-primary" onClick="smartpack_change_shipping_method()" href="#">Update Delivery</a>
            </td></tr>
HTML;

        if ($get_droppoints && $this->sp_method_key_id) {
            echo <<<HTML
                <tr>
                    <td colspan="2">
                        <select name="sp_droppoint" id="sp_droppoint">
HTML;

            $droppoints = $this->smartpack_api->searchDropPoint($this->sp_method_key_id, $this->wooOrder->shipping_address_1, $this->wooOrder->shipping_postcode, $this->wooOrder->shipping_city, $this->wooOrder->shipping_country);


            $pickup_id = get_post_meta($this->wooOrder->get_id(), '_drop_point_id', true);



            foreach ($droppoints as $droppoint) {
                if ($pickup_id == $droppoint['id']) {
                echo <<<HTML
                    <option selected=selected value="{$droppoint['id']}::{$fn($droppoint['address']['street1'])}::{$droppoint['address']['zipcode']}::{$droppoint['address']['city']}::{$fn($droppoint['name'])}::{$droppoint['address']['country']}">
                        {$droppoint['name']} - {$droppoint['address']['street1']} - {$droppoint['address']['zipcode']} - {$droppoint['address']['city']} (Distance {$droppoint['distance']}m)
                    </option>
HTML;
                }
                else {
                echo <<<HTML
                    <option value="{$droppoint['id']}::{$fn($droppoint['address']['street1'])}::{$droppoint['address']['zipcode']}::{$droppoint['address']['city']}::{$fn($droppoint['name'])}::{$droppoint['address']['country']}">
                        {$droppoint['name']} - {$droppoint['address']['street1']} - {$droppoint['address']['zipcode']} - {$droppoint['address']['city']} (Distance {$droppoint['distance']}m)
                    </option>
HTML;
                }


            }

            echo <<<HTML
                </select>&nbsp;
                <a class="button button-primary" onClick="smartpack_change_droppoint()" href="#">Update Droppoint</a>
                </td></tr>
HTML;
        }
    }

    protected function render_table_end()
    {
        echo <<<HTML
                    </table>
                </div>
            </div>
HTML;
    }
}
